# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetOrchestratorConfigResult',
    'AwaitableGetOrchestratorConfigResult',
    'get_orchestrator_config',
    'get_orchestrator_config_output',
]

@pulumi.output_type
class GetOrchestratorConfigResult:
    """
    A collection of values returned by getOrchestratorConfig.
    """
    def __init__(__self__, binpacking=None, commitment_integration=None, disabled=None, distribution=None, id=None, node_preferences=None, orchestrator_id=None, replacement_schedule=None):
        if binpacking and not isinstance(binpacking, dict):
            raise TypeError("Expected argument 'binpacking' to be a dict")
        pulumi.set(__self__, "binpacking", binpacking)
        if commitment_integration and not isinstance(commitment_integration, dict):
            raise TypeError("Expected argument 'commitment_integration' to be a dict")
        pulumi.set(__self__, "commitment_integration", commitment_integration)
        if disabled and not isinstance(disabled, bool):
            raise TypeError("Expected argument 'disabled' to be a bool")
        pulumi.set(__self__, "disabled", disabled)
        if distribution and not isinstance(distribution, dict):
            raise TypeError("Expected argument 'distribution' to be a dict")
        pulumi.set(__self__, "distribution", distribution)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if node_preferences and not isinstance(node_preferences, dict):
            raise TypeError("Expected argument 'node_preferences' to be a dict")
        pulumi.set(__self__, "node_preferences", node_preferences)
        if orchestrator_id and not isinstance(orchestrator_id, str):
            raise TypeError("Expected argument 'orchestrator_id' to be a str")
        pulumi.set(__self__, "orchestrator_id", orchestrator_id)
        if replacement_schedule and not isinstance(replacement_schedule, dict):
            raise TypeError("Expected argument 'replacement_schedule' to be a dict")
        pulumi.set(__self__, "replacement_schedule", replacement_schedule)

    @_builtins.property
    @pulumi.getter
    def binpacking(self) -> Optional['outputs.GetOrchestratorConfigBinpackingResult']:
        """
        Binpacking preferences for Cluster Orchestrator
        """
        return pulumi.get(self, "binpacking")

    @_builtins.property
    @pulumi.getter(name="commitmentIntegration")
    def commitment_integration(self) -> Optional['outputs.GetOrchestratorConfigCommitmentIntegrationResult']:
        """
        Commitment integration configuration for Cluster Orchestrator
        """
        return pulumi.get(self, "commitment_integration")

    @_builtins.property
    @pulumi.getter
    def disabled(self) -> Optional[_builtins.bool]:
        """
        Whether the cluster orchestrator is disabled
        """
        return pulumi.get(self, "disabled")

    @_builtins.property
    @pulumi.getter
    def distribution(self) -> Optional['outputs.GetOrchestratorConfigDistributionResult']:
        """
        Spot and Ondemand Distribution Preferences for workload replicas
        """
        return pulumi.get(self, "distribution")

    @_builtins.property
    @pulumi.getter
    def id(self) -> _builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @_builtins.property
    @pulumi.getter(name="nodePreferences")
    def node_preferences(self) -> Optional['outputs.GetOrchestratorConfigNodePreferencesResult']:
        """
        Node preferences for Cluster Orchestrator
        """
        return pulumi.get(self, "node_preferences")

    @_builtins.property
    @pulumi.getter(name="orchestratorId")
    def orchestrator_id(self) -> _builtins.str:
        """
        ID of the Cluster Orchestrator Object
        """
        return pulumi.get(self, "orchestrator_id")

    @_builtins.property
    @pulumi.getter(name="replacementSchedule")
    def replacement_schedule(self) -> Optional['outputs.GetOrchestratorConfigReplacementScheduleResult']:
        """
        Replacement schedule for Cluster Orchestrator
        """
        return pulumi.get(self, "replacement_schedule")


class AwaitableGetOrchestratorConfigResult(GetOrchestratorConfigResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetOrchestratorConfigResult(
            binpacking=self.binpacking,
            commitment_integration=self.commitment_integration,
            disabled=self.disabled,
            distribution=self.distribution,
            id=self.id,
            node_preferences=self.node_preferences,
            orchestrator_id=self.orchestrator_id,
            replacement_schedule=self.replacement_schedule)


def get_orchestrator_config(binpacking: Optional[Union['GetOrchestratorConfigBinpackingArgs', 'GetOrchestratorConfigBinpackingArgsDict']] = None,
                            commitment_integration: Optional[Union['GetOrchestratorConfigCommitmentIntegrationArgs', 'GetOrchestratorConfigCommitmentIntegrationArgsDict']] = None,
                            disabled: Optional[_builtins.bool] = None,
                            distribution: Optional[Union['GetOrchestratorConfigDistributionArgs', 'GetOrchestratorConfigDistributionArgsDict']] = None,
                            node_preferences: Optional[Union['GetOrchestratorConfigNodePreferencesArgs', 'GetOrchestratorConfigNodePreferencesArgsDict']] = None,
                            orchestrator_id: Optional[_builtins.str] = None,
                            replacement_schedule: Optional[Union['GetOrchestratorConfigReplacementScheduleArgs', 'GetOrchestratorConfigReplacementScheduleArgsDict']] = None,
                            opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetOrchestratorConfigResult:
    """
    Data Source for retrieving Harness CCM ClusterOrchestrator Config.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.cluster.get_orchestrator_config(orchestrator_id="identifier")
    ```


    :param Union['GetOrchestratorConfigBinpackingArgs', 'GetOrchestratorConfigBinpackingArgsDict'] binpacking: Binpacking preferences for Cluster Orchestrator
    :param Union['GetOrchestratorConfigCommitmentIntegrationArgs', 'GetOrchestratorConfigCommitmentIntegrationArgsDict'] commitment_integration: Commitment integration configuration for Cluster Orchestrator
    :param _builtins.bool disabled: Whether the cluster orchestrator is disabled
    :param Union['GetOrchestratorConfigDistributionArgs', 'GetOrchestratorConfigDistributionArgsDict'] distribution: Spot and Ondemand Distribution Preferences for workload replicas
    :param Union['GetOrchestratorConfigNodePreferencesArgs', 'GetOrchestratorConfigNodePreferencesArgsDict'] node_preferences: Node preferences for Cluster Orchestrator
    :param _builtins.str orchestrator_id: ID of the Cluster Orchestrator Object
    :param Union['GetOrchestratorConfigReplacementScheduleArgs', 'GetOrchestratorConfigReplacementScheduleArgsDict'] replacement_schedule: Replacement schedule for Cluster Orchestrator
    """
    __args__ = dict()
    __args__['binpacking'] = binpacking
    __args__['commitmentIntegration'] = commitment_integration
    __args__['disabled'] = disabled
    __args__['distribution'] = distribution
    __args__['nodePreferences'] = node_preferences
    __args__['orchestratorId'] = orchestrator_id
    __args__['replacementSchedule'] = replacement_schedule
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('harness:cluster/getOrchestratorConfig:getOrchestratorConfig', __args__, opts=opts, typ=GetOrchestratorConfigResult).value

    return AwaitableGetOrchestratorConfigResult(
        binpacking=pulumi.get(__ret__, 'binpacking'),
        commitment_integration=pulumi.get(__ret__, 'commitment_integration'),
        disabled=pulumi.get(__ret__, 'disabled'),
        distribution=pulumi.get(__ret__, 'distribution'),
        id=pulumi.get(__ret__, 'id'),
        node_preferences=pulumi.get(__ret__, 'node_preferences'),
        orchestrator_id=pulumi.get(__ret__, 'orchestrator_id'),
        replacement_schedule=pulumi.get(__ret__, 'replacement_schedule'))
def get_orchestrator_config_output(binpacking: Optional[pulumi.Input[Optional[Union['GetOrchestratorConfigBinpackingArgs', 'GetOrchestratorConfigBinpackingArgsDict']]]] = None,
                                   commitment_integration: Optional[pulumi.Input[Optional[Union['GetOrchestratorConfigCommitmentIntegrationArgs', 'GetOrchestratorConfigCommitmentIntegrationArgsDict']]]] = None,
                                   disabled: Optional[pulumi.Input[Optional[_builtins.bool]]] = None,
                                   distribution: Optional[pulumi.Input[Optional[Union['GetOrchestratorConfigDistributionArgs', 'GetOrchestratorConfigDistributionArgsDict']]]] = None,
                                   node_preferences: Optional[pulumi.Input[Optional[Union['GetOrchestratorConfigNodePreferencesArgs', 'GetOrchestratorConfigNodePreferencesArgsDict']]]] = None,
                                   orchestrator_id: Optional[pulumi.Input[_builtins.str]] = None,
                                   replacement_schedule: Optional[pulumi.Input[Optional[Union['GetOrchestratorConfigReplacementScheduleArgs', 'GetOrchestratorConfigReplacementScheduleArgsDict']]]] = None,
                                   opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetOrchestratorConfigResult]:
    """
    Data Source for retrieving Harness CCM ClusterOrchestrator Config.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_harness as harness

    example = harness.cluster.get_orchestrator_config(orchestrator_id="identifier")
    ```


    :param Union['GetOrchestratorConfigBinpackingArgs', 'GetOrchestratorConfigBinpackingArgsDict'] binpacking: Binpacking preferences for Cluster Orchestrator
    :param Union['GetOrchestratorConfigCommitmentIntegrationArgs', 'GetOrchestratorConfigCommitmentIntegrationArgsDict'] commitment_integration: Commitment integration configuration for Cluster Orchestrator
    :param _builtins.bool disabled: Whether the cluster orchestrator is disabled
    :param Union['GetOrchestratorConfigDistributionArgs', 'GetOrchestratorConfigDistributionArgsDict'] distribution: Spot and Ondemand Distribution Preferences for workload replicas
    :param Union['GetOrchestratorConfigNodePreferencesArgs', 'GetOrchestratorConfigNodePreferencesArgsDict'] node_preferences: Node preferences for Cluster Orchestrator
    :param _builtins.str orchestrator_id: ID of the Cluster Orchestrator Object
    :param Union['GetOrchestratorConfigReplacementScheduleArgs', 'GetOrchestratorConfigReplacementScheduleArgsDict'] replacement_schedule: Replacement schedule for Cluster Orchestrator
    """
    __args__ = dict()
    __args__['binpacking'] = binpacking
    __args__['commitmentIntegration'] = commitment_integration
    __args__['disabled'] = disabled
    __args__['distribution'] = distribution
    __args__['nodePreferences'] = node_preferences
    __args__['orchestratorId'] = orchestrator_id
    __args__['replacementSchedule'] = replacement_schedule
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('harness:cluster/getOrchestratorConfig:getOrchestratorConfig', __args__, opts=opts, typ=GetOrchestratorConfigResult)
    return __ret__.apply(lambda __response__: GetOrchestratorConfigResult(
        binpacking=pulumi.get(__response__, 'binpacking'),
        commitment_integration=pulumi.get(__response__, 'commitment_integration'),
        disabled=pulumi.get(__response__, 'disabled'),
        distribution=pulumi.get(__response__, 'distribution'),
        id=pulumi.get(__response__, 'id'),
        node_preferences=pulumi.get(__response__, 'node_preferences'),
        orchestrator_id=pulumi.get(__response__, 'orchestrator_id'),
        replacement_schedule=pulumi.get(__response__, 'replacement_schedule')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['SecurityGovernanceRuleArgs', 'SecurityGovernanceRule']

@pulumi.input_type
class SecurityGovernanceRuleArgs:
    def __init__(__self__, *,
                 condition_ids: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]],
                 org_id: pulumi.Input[_builtins.str],
                 project_id: pulumi.Input[_builtins.str],
                 time_windows: pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        The set of arguments for constructing a SecurityGovernanceRule resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] condition_ids: List of condition IDs associated with this rule
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance rule
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance rule
        :param pulumi.Input[_builtins.str] description: Description of the security governance rule
        :param pulumi.Input[_builtins.bool] is_enabled: Whether the rule is enabled
        :param pulumi.Input[_builtins.str] name: Name of the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_group_ids: List of user group IDs associated with this rule
        """
        pulumi.set(__self__, "condition_ids", condition_ids)
        pulumi.set(__self__, "org_id", org_id)
        pulumi.set(__self__, "project_id", project_id)
        pulumi.set(__self__, "time_windows", time_windows)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_group_ids is not None:
            pulumi.set(__self__, "user_group_ids", user_group_ids)

    @_builtins.property
    @pulumi.getter(name="conditionIds")
    def condition_ids(self) -> pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]:
        """
        List of condition IDs associated with this rule
        """
        return pulumi.get(self, "condition_ids")

    @condition_ids.setter
    def condition_ids(self, value: pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]):
        pulumi.set(self, "condition_ids", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Input[_builtins.str]:
        """
        The organization ID of the security governance rule
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Input[_builtins.str]:
        """
        The project ID of the security governance rule
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter(name="timeWindows")
    def time_windows(self) -> pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]]:
        return pulumi.get(self, "time_windows")

    @time_windows.setter
    def time_windows(self, value: pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]]):
        pulumi.set(self, "time_windows", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the security governance rule
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the rule is enabled
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the security governance rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the security governance rule
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userGroupIds")
    def user_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user group IDs associated with this rule
        """
        return pulumi.get(self, "user_group_ids")

    @user_group_ids.setter
    def user_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_group_ids", value)


@pulumi.input_type
class _SecurityGovernanceRuleState:
    def __init__(__self__, *,
                 condition_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 time_windows: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]]] = None,
                 user_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering SecurityGovernanceRule resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] condition_ids: List of condition IDs associated with this rule
        :param pulumi.Input[_builtins.str] description: Description of the security governance rule
        :param pulumi.Input[_builtins.bool] is_enabled: Whether the rule is enabled
        :param pulumi.Input[_builtins.str] name: Name of the security governance rule
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance rule
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_group_ids: List of user group IDs associated with this rule
        """
        if condition_ids is not None:
            pulumi.set(__self__, "condition_ids", condition_ids)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if is_enabled is not None:
            pulumi.set(__self__, "is_enabled", is_enabled)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if time_windows is not None:
            pulumi.set(__self__, "time_windows", time_windows)
        if user_group_ids is not None:
            pulumi.set(__self__, "user_group_ids", user_group_ids)

    @_builtins.property
    @pulumi.getter(name="conditionIds")
    def condition_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of condition IDs associated with this rule
        """
        return pulumi.get(self, "condition_ids")

    @condition_ids.setter
    def condition_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "condition_ids", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the security governance rule
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Whether the rule is enabled
        """
        return pulumi.get(self, "is_enabled")

    @is_enabled.setter
    def is_enabled(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "is_enabled", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the security governance rule
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The organization ID of the security governance rule
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The project ID of the security governance rule
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags for the security governance rule
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="timeWindows")
    def time_windows(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]]]:
        return pulumi.get(self, "time_windows")

    @time_windows.setter
    def time_windows(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SecurityGovernanceRuleTimeWindowArgs']]]]):
        pulumi.set(self, "time_windows", value)

    @_builtins.property
    @pulumi.getter(name="userGroupIds")
    def user_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        List of user group IDs associated with this rule
        """
        return pulumi.get(self, "user_group_ids")

    @user_group_ids.setter
    def user_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "user_group_ids", value)


@pulumi.type_token("harness:chaos/securityGovernanceRule:SecurityGovernanceRule")
class SecurityGovernanceRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 time_windows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGovernanceRuleTimeWindowArgs', 'SecurityGovernanceRuleTimeWindowArgsDict']]]]] = None,
                 user_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        """
        Resource for managing a Harness Chaos Security Governance Rule

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # K8s Rule
        example = harness.chaos.SecurityGovernanceRule("example",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        # Linux Rule
        linux_rule = harness.chaos.SecurityGovernanceRule("linux_rule",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        # Windows Rule
        windows_rule = harness.chaos.SecurityGovernanceRule("windows_rule",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Security Governance Rule

        ```sh
        $ pulumi import harness:chaos/securityGovernanceRule:SecurityGovernanceRule example org_id/project_id/rule_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] condition_ids: List of condition IDs associated with this rule
        :param pulumi.Input[_builtins.str] description: Description of the security governance rule
        :param pulumi.Input[_builtins.bool] is_enabled: Whether the rule is enabled
        :param pulumi.Input[_builtins.str] name: Name of the security governance rule
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance rule
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_group_ids: List of user group IDs associated with this rule
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: SecurityGovernanceRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for managing a Harness Chaos Security Governance Rule

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        # K8s Rule
        example = harness.chaos.SecurityGovernanceRule("example",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        # Linux Rule
        linux_rule = harness.chaos.SecurityGovernanceRule("linux_rule",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        # Windows Rule
        windows_rule = harness.chaos.SecurityGovernanceRule("windows_rule",
            org_id="<org_id>",
            project_id="<project_id>",
            name="<name>",
            description="<description>",
            is_enabled=True,
            condition_ids=["<condition_id>"],
            user_group_ids=["_project_all_users"],
            tags=[
                "<tag1>",
                "<tag2>",
            ],
            time_windows=[{
                "time_zone": "UTC",
                "start_time": 1711238400000,
                "duration": "24h",
                "recurrence": {
                    "type": "Daily",
                    "until": -1,
                },
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import Project level Chaos Security Governance Rule

        ```sh
        $ pulumi import harness:chaos/securityGovernanceRule:SecurityGovernanceRule example org_id/project_id/rule_id
        ```

        :param str resource_name: The name of the resource.
        :param SecurityGovernanceRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(SecurityGovernanceRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 condition_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 time_windows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGovernanceRuleTimeWindowArgs', 'SecurityGovernanceRuleTimeWindowArgsDict']]]]] = None,
                 user_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = SecurityGovernanceRuleArgs.__new__(SecurityGovernanceRuleArgs)

            if condition_ids is None and not opts.urn:
                raise TypeError("Missing required property 'condition_ids'")
            __props__.__dict__["condition_ids"] = condition_ids
            __props__.__dict__["description"] = description
            __props__.__dict__["is_enabled"] = is_enabled
            __props__.__dict__["name"] = name
            if org_id is None and not opts.urn:
                raise TypeError("Missing required property 'org_id'")
            __props__.__dict__["org_id"] = org_id
            if project_id is None and not opts.urn:
                raise TypeError("Missing required property 'project_id'")
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            if time_windows is None and not opts.urn:
                raise TypeError("Missing required property 'time_windows'")
            __props__.__dict__["time_windows"] = time_windows
            __props__.__dict__["user_group_ids"] = user_group_ids
        super(SecurityGovernanceRule, __self__).__init__(
            'harness:chaos/securityGovernanceRule:SecurityGovernanceRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            condition_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            is_enabled: Optional[pulumi.Input[_builtins.bool]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            time_windows: Optional[pulumi.Input[Sequence[pulumi.Input[Union['SecurityGovernanceRuleTimeWindowArgs', 'SecurityGovernanceRuleTimeWindowArgsDict']]]]] = None,
            user_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None) -> 'SecurityGovernanceRule':
        """
        Get an existing SecurityGovernanceRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] condition_ids: List of condition IDs associated with this rule
        :param pulumi.Input[_builtins.str] description: Description of the security governance rule
        :param pulumi.Input[_builtins.bool] is_enabled: Whether the rule is enabled
        :param pulumi.Input[_builtins.str] name: Name of the security governance rule
        :param pulumi.Input[_builtins.str] org_id: The organization ID of the security governance rule
        :param pulumi.Input[_builtins.str] project_id: The project ID of the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags for the security governance rule
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] user_group_ids: List of user group IDs associated with this rule
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _SecurityGovernanceRuleState.__new__(_SecurityGovernanceRuleState)

        __props__.__dict__["condition_ids"] = condition_ids
        __props__.__dict__["description"] = description
        __props__.__dict__["is_enabled"] = is_enabled
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["time_windows"] = time_windows
        __props__.__dict__["user_group_ids"] = user_group_ids
        return SecurityGovernanceRule(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="conditionIds")
    def condition_ids(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        List of condition IDs associated with this rule
        """
        return pulumi.get(self, "condition_ids")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the security governance rule
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="isEnabled")
    def is_enabled(self) -> pulumi.Output[Optional[_builtins.bool]]:
        """
        Whether the rule is enabled
        """
        return pulumi.get(self, "is_enabled")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the security governance rule
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[_builtins.str]:
        """
        The organization ID of the security governance rule
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[_builtins.str]:
        """
        The project ID of the security governance rule
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags for the security governance rule
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter(name="timeWindows")
    def time_windows(self) -> pulumi.Output[Sequence['outputs.SecurityGovernanceRuleTimeWindow']]:
        return pulumi.get(self, "time_windows")

    @_builtins.property
    @pulumi.getter(name="userGroupIds")
    def user_group_ids(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        List of user group IDs associated with this rule
        """
        return pulumi.get(self, "user_group_ids")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EcsArgs', 'Ecs']

@pulumi.input_type
class EcsArgs:
    def __init__(__self__, *,
                 app_id: pulumi.Input[_builtins.str],
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]] = None):
        """
        The set of arguments for constructing a Ecs resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application the service belongs to
        :param pulumi.Input[_builtins.str] description: Description of th service
        :param pulumi.Input[_builtins.str] name: Name of the service
        :param pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]] variables: Variables to be used in the service
        """
        pulumi.set(__self__, "app_id", app_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Input[_builtins.str]:
        """
        The id of the application the service belongs to
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of th service
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the service
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]]:
        """
        Variables to be used in the service
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]]):
        pulumi.set(self, "variables", value)


@pulumi.input_type
class _EcsState:
    def __init__(__self__, *,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]] = None):
        """
        Input properties used for looking up and filtering Ecs resources.
        :param pulumi.Input[_builtins.str] app_id: The id of the application the service belongs to
        :param pulumi.Input[_builtins.str] description: Description of th service
        :param pulumi.Input[_builtins.str] name: Name of the service
        :param pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]] variables: Variables to be used in the service
        """
        if app_id is not None:
            pulumi.set(__self__, "app_id", app_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if variables is not None:
            pulumi.set(__self__, "variables", variables)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The id of the application the service belongs to
        """
        return pulumi.get(self, "app_id")

    @app_id.setter
    def app_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "app_id", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of th service
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the service
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def variables(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]]:
        """
        Variables to be used in the service
        """
        return pulumi.get(self, "variables")

    @variables.setter
    def variables(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EcsVariableArgs']]]]):
        pulumi.set(self, "variables", value)


@pulumi.type_token("harness:service/ecs:Ecs")
class Ecs(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcsVariableArgs', 'EcsVariableArgsDict']]]]] = None,
                 __props__=None):
        """
        Resource for creating an AWS ECS service. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.Application("example", name="example")
        example_ecs = harness.service.Ecs("example",
            app_id=example.id,
            name="ecs-example-service",
            description="Service for deploying AWS ECS tasks.")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id and service id

        ```sh
        $ pulumi import harness:service/ecs:Ecs example <app_id>/<svc_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application the service belongs to
        :param pulumi.Input[_builtins.str] description: Description of th service
        :param pulumi.Input[_builtins.str] name: Name of the service
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcsVariableArgs', 'EcsVariableArgsDict']]]] variables: Variables to be used in the service
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EcsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating an AWS ECS service. This resource uses the config-as-code API's. When updating the `name` or `path` of this resource you should typically also set the `create_before_destroy = true` lifecycle setting.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.Application("example", name="example")
        example_ecs = harness.service.Ecs("example",
            app_id=example.id,
            name="ecs-example-service",
            description="Service for deploying AWS ECS tasks.")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import using the Harness application id and service id

        ```sh
        $ pulumi import harness:service/ecs:Ecs example <app_id>/<svc_id>
        ```

        :param str resource_name: The name of the resource.
        :param EcsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EcsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_id: Optional[pulumi.Input[_builtins.str]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcsVariableArgs', 'EcsVariableArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EcsArgs.__new__(EcsArgs)

            if app_id is None and not opts.urn:
                raise TypeError("Missing required property 'app_id'")
            __props__.__dict__["app_id"] = app_id
            __props__.__dict__["description"] = description
            __props__.__dict__["name"] = name
            __props__.__dict__["variables"] = variables
        super(Ecs, __self__).__init__(
            'harness:service/ecs:Ecs',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_id: Optional[pulumi.Input[_builtins.str]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            variables: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EcsVariableArgs', 'EcsVariableArgsDict']]]]] = None) -> 'Ecs':
        """
        Get an existing Ecs resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] app_id: The id of the application the service belongs to
        :param pulumi.Input[_builtins.str] description: Description of th service
        :param pulumi.Input[_builtins.str] name: Name of the service
        :param pulumi.Input[Sequence[pulumi.Input[Union['EcsVariableArgs', 'EcsVariableArgsDict']]]] variables: Variables to be used in the service
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EcsState.__new__(_EcsState)

        __props__.__dict__["app_id"] = app_id
        __props__.__dict__["description"] = description
        __props__.__dict__["name"] = name
        __props__.__dict__["variables"] = variables
        return Ecs(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="appId")
    def app_id(self) -> pulumi.Output[_builtins.str]:
        """
        The id of the application the service belongs to
        """
        return pulumi.get(self, "app_id")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of th service
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the service
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter
    def variables(self) -> pulumi.Output[Optional[Sequence['outputs.EcsVariable']]]:
        """
        Variables to be used in the service
        """
        return pulumi.get(self, "variables")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['PrometheusConnectorArgs', 'PrometheusConnector']

@pulumi.input_type
class PrometheusConnectorArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 url: pulumi.Input[_builtins.str],
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 headers: Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a PrometheusConnector resource.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] url: URL of the Prometheus server.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]] headers: Headers.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] password_ref: Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] user_name: User name.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "url", url)
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if password_ref is not None:
            pulumi.set(__self__, "password_ref", password_ref)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Input[_builtins.str]:
        """
        URL of the Prometheus server.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]]:
        """
        Headers.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]]):
        pulumi.set(self, "headers", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="passwordRef")
    def password_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        """
        return pulumi.get(self, "password_ref")

    @password_ref.setter
    def password_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password_ref", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _PrometheusConnectorState:
    def __init__(__self__, *,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 headers: Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering PrometheusConnector resources.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]] headers: Headers.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] password_ref: Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] url: URL of the Prometheus server.
        :param pulumi.Input[_builtins.str] user_name: User name.
        """
        if delegate_selectors is not None:
            pulumi.set(__self__, "delegate_selectors", delegate_selectors)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if headers is not None:
            pulumi.set(__self__, "headers", headers)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if password_ref is not None:
            pulumi.set(__self__, "password_ref", password_ref)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if url is not None:
            pulumi.set(__self__, "url", url)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @delegate_selectors.setter
    def delegate_selectors(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "delegate_selectors", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter
    def headers(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]]:
        """
        Headers.
        """
        return pulumi.get(self, "headers")

    @headers.setter
    def headers(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['PrometheusConnectorHeaderArgs']]]]):
        pulumi.set(self, "headers", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="passwordRef")
    def password_ref(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        """
        return pulumi.get(self, "password_ref")

    @password_ref.setter
    def password_ref(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "password_ref", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "tags", value)

    @_builtins.property
    @pulumi.getter
    def url(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        URL of the Prometheus server.
        """
        return pulumi.get(self, "url")

    @url.setter
    def url(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "url", value)

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        User name.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "user_name", value)


@pulumi.type_token("harness:platform/prometheusConnector:PrometheusConnector")
class PrometheusConnector(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrometheusConnectorHeaderArgs', 'PrometheusConnectorHeaderArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Prometheus connector.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.PrometheusConnector("example",
            identifier="idntifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            url="https://prometheus.com/",
            delegate_selectors=["harness-delegate"],
            user_name="user_name",
            password_ref="account.secret_identifier",
            headers=[{
                "encrypted_value_ref": "account.secret_identifier",
                "value_encrypted": True,
                "key": "key",
                "value": "value",
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <connector_id>
        ```

        Import org level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <ord_id>/<connector_id>
        ```

        Import project level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrometheusConnectorHeaderArgs', 'PrometheusConnectorHeaderArgsDict']]]] headers: Headers.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] password_ref: Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] url: URL of the Prometheus server.
        :param pulumi.Input[_builtins.str] user_name: User name.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: PrometheusConnectorArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Prometheus connector.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.PrometheusConnector("example",
            identifier="idntifier",
            name="name",
            description="test",
            tags=["foo:bar"],
            url="https://prometheus.com/",
            delegate_selectors=["harness-delegate"],
            user_name="user_name",
            password_ref="account.secret_identifier",
            headers=[{
                "encrypted_value_ref": "account.secret_identifier",
                "value_encrypted": True,
                "key": "key",
                "value": "value",
            }])
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <connector_id>
        ```

        Import org level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <ord_id>/<connector_id>
        ```

        Import project level prometheus connector

        ```sh
        $ pulumi import harness:platform/prometheusConnector:PrometheusConnector example <org_id>/<project_id>/<connector_id>
        ```

        :param str resource_name: The name of the resource.
        :param PrometheusConnectorArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(PrometheusConnectorArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrometheusConnectorHeaderArgs', 'PrometheusConnectorHeaderArgsDict']]]]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 password_ref: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 url: Optional[pulumi.Input[_builtins.str]] = None,
                 user_name: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = PrometheusConnectorArgs.__new__(PrometheusConnectorArgs)

            __props__.__dict__["delegate_selectors"] = delegate_selectors
            __props__.__dict__["description"] = description
            __props__.__dict__["headers"] = headers
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["name"] = name
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["password_ref"] = password_ref
            __props__.__dict__["project_id"] = project_id
            __props__.__dict__["tags"] = tags
            if url is None and not opts.urn:
                raise TypeError("Missing required property 'url'")
            __props__.__dict__["url"] = url
            __props__.__dict__["user_name"] = user_name
        super(PrometheusConnector, __self__).__init__(
            'harness:platform/prometheusConnector:PrometheusConnector',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            delegate_selectors: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            headers: Optional[pulumi.Input[Sequence[pulumi.Input[Union['PrometheusConnectorHeaderArgs', 'PrometheusConnectorHeaderArgsDict']]]]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            password_ref: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            url: Optional[pulumi.Input[_builtins.str]] = None,
            user_name: Optional[pulumi.Input[_builtins.str]] = None) -> 'PrometheusConnector':
        """
        Get an existing PrometheusConnector resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] delegate_selectors: Tags to filter delegates for connection.
        :param pulumi.Input[_builtins.str] description: Description of the resource.
        :param pulumi.Input[Sequence[pulumi.Input[Union['PrometheusConnectorHeaderArgs', 'PrometheusConnectorHeaderArgsDict']]]] headers: Headers.
        :param pulumi.Input[_builtins.str] identifier: Unique identifier of the resource.
        :param pulumi.Input[_builtins.str] name: Name of the resource.
        :param pulumi.Input[_builtins.str] org_id: Unique identifier of the organization.
        :param pulumi.Input[_builtins.str] password_ref: Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        :param pulumi.Input[_builtins.str] project_id: Unique identifier of the project.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] tags: Tags to associate with the resource.
        :param pulumi.Input[_builtins.str] url: URL of the Prometheus server.
        :param pulumi.Input[_builtins.str] user_name: User name.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _PrometheusConnectorState.__new__(_PrometheusConnectorState)

        __props__.__dict__["delegate_selectors"] = delegate_selectors
        __props__.__dict__["description"] = description
        __props__.__dict__["headers"] = headers
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["name"] = name
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["password_ref"] = password_ref
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["tags"] = tags
        __props__.__dict__["url"] = url
        __props__.__dict__["user_name"] = user_name
        return PrometheusConnector(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="delegateSelectors")
    def delegate_selectors(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to filter delegates for connection.
        """
        return pulumi.get(self, "delegate_selectors")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the resource.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter
    def headers(self) -> pulumi.Output[Optional[Sequence['outputs.PrometheusConnectorHeader']]]:
        """
        Headers.
        """
        return pulumi.get(self, "headers")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the resource.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the resource.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the organization.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="passwordRef")
    def password_ref(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Reference to the Harness secret containing the password. To reference a secret at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference a secret at the account scope, prefix 'account` to the expression: account.{identifier}.
        """
        return pulumi.get(self, "password_ref")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Unique identifier of the project.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Optional[Sequence[_builtins.str]]]:
        """
        Tags to associate with the resource.
        """
        return pulumi.get(self, "tags")

    @_builtins.property
    @pulumi.getter
    def url(self) -> pulumi.Output[_builtins.str]:
        """
        URL of the Prometheus server.
        """
        return pulumi.get(self, "url")

    @_builtins.property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        User name.
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .app_dynamics_connector import *
from .artifactory_connector import *
from .aws_cc_connector import *
from .aws_connector import *
from .aws_kms_connector import *
from .aws_secret_manager_connector import *
from .azure_cloud_cost_connector import *
from .azure_cloud_provider_connector import *
from .azure_key_vault_connector import *
from .bitbucket_connector import *
from .central_notification_channel import *
from .central_notification_rule import *
from .connector_azure_artifacts import *
from .connector_azure_repo import *
from .connector_custom_secret_manager import *
from .connector_customhealthsource import *
from .connector_gcp_kms import *
from .connector_jdbc import *
from .connector_pdc import *
from .connector_rancher import *
from .dashboard_folders import *
from .dashboards import *
from .datadog_connector import *
from .db_instance import *
from .db_schema import *
from .default_notification_template_set import *
from .delegatetoken import *
from .docker_connector import *
from .dynatrace_connector import *
from .elasticsearch_connector import *
from .environment import *
from .environment_clusters_mapping import *
from .environment_group import *
from .environment_service_overrides import *
from .feature_flag import *
from .feature_flag_api_key import *
from .feature_flag_target import *
from .feature_flag_target_group import *
from .file_store_file import *
from .file_store_folder import *
from .filters import *
from .gcp_cloud_cost_connector import *
from .gcp_connector import *
from .gcp_secret_manager_connector import *
from .get_api_key import *
from .get_app_dynamics_connector import *
from .get_artifactory_connector import *
from .get_aws_cc_connector import *
from .get_aws_connector import *
from .get_aws_kms_connector import *
from .get_aws_secret_manager_connector import *
from .get_azure_cloud_cost_connector import *
from .get_azure_cloud_provider_connector import *
from .get_azure_key_vault_connector import *
from .get_bitbucket_connector import *
from .get_ccm_filters import *
from .get_central_notification_channel import *
from .get_central_notification_rule import *
from .get_connector_azure_repo import *
from .get_connector_custom_secret_manager import *
from .get_connector_customhealthsource import *
from .get_connector_gcp_kms import *
from .get_connector_jdbc import *
from .get_connector_pdc import *
from .get_connector_rancher import *
from .get_current_account import *
from .get_current_user import *
from .get_dashboard_folders import *
from .get_dashboards import *
from .get_datadog_connector import *
from .get_db_instance import *
from .get_db_schema import *
from .get_default_notification_template_set import *
from .get_delegatetoken import *
from .get_docker_connector import *
from .get_dynatrace_connector import *
from .get_elasticsearch_connector import *
from .get_environment import *
from .get_environment_clusters_mapping import *
from .get_environment_group import *
from .get_environment_list import *
from .get_environment_service_overrides import *
from .get_file_store_file import *
from .get_file_store_folder import *
from .get_filters import *
from .get_gcp_cloud_cost_connector import *
from .get_gcp_connector import *
from .get_gcp_projects import *
from .get_gcp_secret_manager_connector import *
from .get_git_connector import *
from .get_github_connector import *
from .get_gitlab_connector import *
from .get_gitops_agent import *
from .get_gitops_agent_deploy_yaml import *
from .get_gitops_agent_operator_yaml import *
from .get_gitops_app_project import *
from .get_gitops_app_project_mapping import *
from .get_gitops_applications import *
from .get_gitops_cluster import *
from .get_gitops_filters import *
from .get_gitops_gnupg import *
from .get_gitops_repo_cert import *
from .get_gitops_repo_cred import *
from .get_gitops_repository import *
from .get_gitx_webhook import *
from .get_har_registry import *
from .get_helm_connector import *
from .get_iacm_default_pipeline import *
from .get_idp_catalog_entity import *
from .get_idp_environment import *
from .get_idp_environment_blueprint import *
from .get_infra_module import *
from .get_infra_module_testing import *
from .get_infra_modules import *
from .get_infra_variable_set import *
from .get_infrastructure import *
from .get_input_set import *
from .get_jenkins_connector import *
from .get_jira_connector import *
from .get_kubernetes_cloud_cost_connector import *
from .get_kubernetes_connector import *
from .get_manual_freeze import *
from .get_monitored_service import *
from .get_nexus_connector import *
from .get_notification_rule import *
from .get_oci_helm_connector import *
from .get_organization import *
from .get_overrides import *
from .get_pagerduty_connector import *
from .get_permissions import *
from .get_pipeline import *
from .get_pipeline_central_notification_rule import *
from .get_pipeline_filters import *
from .get_pipeline_list import *
from .get_policy import *
from .get_policy_set import *
from .get_project import *
from .get_project_list import *
from .get_prometheus_connector import *
from .get_provider import *
from .get_repo import *
from .get_repo_rule_branch import *
from .get_repo_webhook import *
from .get_resource_group import *
from .get_role_assignments import *
from .get_roles import *
from .get_secret_file import *
from .get_secret_sshkey import *
from .get_secret_text import *
from .get_secret_winrm import *
from .get_service import *
from .get_service_account import *
from .get_service_list import *
from .get_service_now_connector import *
from .get_service_overrides_v2 import *
from .get_slo import *
from .get_splunk_connector import *
from .get_spot_connector import *
from .get_sumologic_connector import *
from .get_tas_connector import *
from .get_template import *
from .get_template_filters import *
from .get_terraform_cloud_connector import *
from .get_token import *
from .get_triggers import *
from .get_user import *
from .get_usergroup import *
from .get_variables import *
from .get_vault_connector import *
from .get_workspace import *
from .get_workspace_output_value import *
from .git_connector import *
from .git_ops_agent import *
from .git_ops_applications import *
from .git_ops_cluster import *
from .git_ops_gnupg import *
from .git_ops_repo_cert import *
from .git_ops_repo_cred import *
from .git_ops_repository import *
from .github_connector import *
from .gitlab_connector import *
from .gitops_app_project import *
from .gitops_app_project_mapping import *
from .gitops_applicationset import *
from .gitops_filters import *
from .gitx_webhook import *
from .har_registry import *
from .helm_connector import *
from .iacm_default_pipeline import *
from .idp_catalog_entity import *
from .idp_environment import *
from .idp_environment_blueprint import *
from .infra_module import *
from .infra_module_testing import *
from .infra_variable_set import *
from .infrastructure import *
from .input_set import *
from .ip_allowlist import *
from .jenkins_connector import *
from .jira_connector import *
from .kubernetes_cloud_cost_connector import *
from .kubernetes_connector import *
from .manual_freeze import *
from .monitored_service import *
from .newrelic_connector import *
from .nexus_connector import *
from .notification_rule import *
from .oci_helm_connector import *
from .organization import *
from .overrides import *
from .pagerduty_connector import *
from .pipeline import *
from .pipeline_central_notification_rule import *
from .pipeline_filters import *
from .policy import *
from .policy_set import *
from .project import *
from .prometheus_connector import *
from .provider import *
from .repo import *
from .repo_rule_branch import *
from .repo_webhook import *
from .resource_group import *
from .role_assignments import *
from .roles import *
from .secret_file import *
from .secret_sshkey import *
from .secret_text import *
from .secret_winrm import *
from .service import *
from .service_account import *
from .service_now_connector import *
from .service_overrides_v2 import *
from .slo import *
from .splunk_connector import *
from .spot_connector import *
from .sumologic_connector import *
from .tas_connector import *
from .template import *
from .template_filters import *
from .terraform_cloud_connector import *
from .token import *
from .triggers import *
from .user import *
from .usergroup import *
from .variables import *
from .vault_connector import *
from .workspace import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EnvironmentGroupArgs', 'EnvironmentGroup']

@pulumi.input_type
class EnvironmentGroupArgs:
    def __init__(__self__, *,
                 identifier: pulumi.Input[_builtins.str],
                 yaml: pulumi.Input[_builtins.str],
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None):
        """
        The set of arguments for constructing a EnvironmentGroup resource.
        :param pulumi.Input[_builtins.str] identifier: identifier of the environment group.
        :param pulumi.Input[_builtins.str] yaml: Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        :param pulumi.Input[_builtins.str] color: Color of the environment group.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of environment group
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment group.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment group.
        """
        pulumi.set(__self__, "identifier", identifier)
        pulumi.set(__self__, "yaml", yaml)
        if color is not None:
            pulumi.set(__self__, "color", color)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Input[_builtins.str]:
        """
        identifier of the environment group.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Input[_builtins.str]:
        """
        Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "yaml", value)

    @_builtins.property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Color of the environment group.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "color", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of environment group
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        org_id of the environment group.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project_id of the environment group.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)


@pulumi.input_type
class _EnvironmentGroupState:
    def __init__(__self__, *,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None):
        """
        Input properties used for looking up and filtering EnvironmentGroup resources.
        :param pulumi.Input[_builtins.str] color: Color of the environment group.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of environment group
        :param pulumi.Input[_builtins.str] identifier: identifier of the environment group.
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment group.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment group.
        :param pulumi.Input[_builtins.str] yaml: Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        if color is not None:
            pulumi.set(__self__, "color", color)
        if force_delete is not None:
            pulumi.set(__self__, "force_delete", force_delete)
        if identifier is not None:
            pulumi.set(__self__, "identifier", identifier)
        if org_id is not None:
            pulumi.set(__self__, "org_id", org_id)
        if project_id is not None:
            pulumi.set(__self__, "project_id", project_id)
        if yaml is not None:
            pulumi.set(__self__, "yaml", yaml)

    @_builtins.property
    @pulumi.getter
    def color(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Color of the environment group.
        """
        return pulumi.get(self, "color")

    @color.setter
    def color(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "color", value)

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> Optional[pulumi.Input[_builtins.bool]]:
        """
        Enable this flag for force deletion of environment group
        """
        return pulumi.get(self, "force_delete")

    @force_delete.setter
    def force_delete(self, value: Optional[pulumi.Input[_builtins.bool]]):
        pulumi.set(self, "force_delete", value)

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        identifier of the environment group.
        """
        return pulumi.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "identifier", value)

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        org_id of the environment group.
        """
        return pulumi.get(self, "org_id")

    @org_id.setter
    def org_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "org_id", value)

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        project_id of the environment group.
        """
        return pulumi.get(self, "project_id")

    @project_id.setter
    def project_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "project_id", value)

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")

    @yaml.setter
    def yaml(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "yaml", value)


@pulumi.type_token("harness:platform/environmentGroup:EnvironmentGroup")
class EnvironmentGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        """
        Resource for creating a Harness environment group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.EnvironmentGroup("example",
            identifier="identifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            color="#0063F7",
            yaml=\"\"\"environmentGroup:
          name: \\"name\\"
          identifier: \\"identifier\\"
          description: \\"temp\\"
          orgIdentifier: \\"orgIdentifer\\"
          projectIdentifier: \\"projectIdentifier\\"
          envIdentifiers: []
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <environment_group_id>
        ```

        Import org level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <org_id>/<environment_group_id>
        ```

        Import project level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <org_id>/<project_id>/<environment_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] color: Color of the environment group.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of environment group
        :param pulumi.Input[_builtins.str] identifier: identifier of the environment group.
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment group.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment group.
        :param pulumi.Input[_builtins.str] yaml: Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EnvironmentGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for creating a Harness environment group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        example = harness.platform.EnvironmentGroup("example",
            identifier="identifier",
            org_id="orgIdentifer",
            project_id="projectIdentifier",
            color="#0063F7",
            yaml=\"\"\"environmentGroup:
          name: \\"name\\"
          identifier: \\"identifier\\"
          description: \\"temp\\"
          orgIdentifier: \\"orgIdentifer\\"
          projectIdentifier: \\"projectIdentifier\\"
          envIdentifiers: []
        \"\"\")
        ```

        ## Import

        The `pulumi import` command can be used, for example:

        Import account level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <environment_group_id>
        ```

        Import org level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <org_id>/<environment_group_id>
        ```

        Import project level environment group.

        ```sh
        $ pulumi import harness:platform/environmentGroup:EnvironmentGroup example <org_id>/<project_id>/<environment_group_id>
        ```

        :param str resource_name: The name of the resource.
        :param EnvironmentGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EnvironmentGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 color: Optional[pulumi.Input[_builtins.str]] = None,
                 force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
                 identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 org_id: Optional[pulumi.Input[_builtins.str]] = None,
                 project_id: Optional[pulumi.Input[_builtins.str]] = None,
                 yaml: Optional[pulumi.Input[_builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EnvironmentGroupArgs.__new__(EnvironmentGroupArgs)

            __props__.__dict__["color"] = color
            __props__.__dict__["force_delete"] = force_delete
            if identifier is None and not opts.urn:
                raise TypeError("Missing required property 'identifier'")
            __props__.__dict__["identifier"] = identifier
            __props__.__dict__["org_id"] = org_id
            __props__.__dict__["project_id"] = project_id
            if yaml is None and not opts.urn:
                raise TypeError("Missing required property 'yaml'")
            __props__.__dict__["yaml"] = yaml
        super(EnvironmentGroup, __self__).__init__(
            'harness:platform/environmentGroup:EnvironmentGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            color: Optional[pulumi.Input[_builtins.str]] = None,
            force_delete: Optional[pulumi.Input[_builtins.bool]] = None,
            identifier: Optional[pulumi.Input[_builtins.str]] = None,
            org_id: Optional[pulumi.Input[_builtins.str]] = None,
            project_id: Optional[pulumi.Input[_builtins.str]] = None,
            yaml: Optional[pulumi.Input[_builtins.str]] = None) -> 'EnvironmentGroup':
        """
        Get an existing EnvironmentGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] color: Color of the environment group.
        :param pulumi.Input[_builtins.bool] force_delete: Enable this flag for force deletion of environment group
        :param pulumi.Input[_builtins.str] identifier: identifier of the environment group.
        :param pulumi.Input[_builtins.str] org_id: org_id of the environment group.
        :param pulumi.Input[_builtins.str] project_id: project_id of the environment group.
        :param pulumi.Input[_builtins.str] yaml: Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EnvironmentGroupState.__new__(_EnvironmentGroupState)

        __props__.__dict__["color"] = color
        __props__.__dict__["force_delete"] = force_delete
        __props__.__dict__["identifier"] = identifier
        __props__.__dict__["org_id"] = org_id
        __props__.__dict__["project_id"] = project_id
        __props__.__dict__["yaml"] = yaml
        return EnvironmentGroup(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter
    def color(self) -> pulumi.Output[_builtins.str]:
        """
        Color of the environment group.
        """
        return pulumi.get(self, "color")

    @_builtins.property
    @pulumi.getter(name="forceDelete")
    def force_delete(self) -> pulumi.Output[_builtins.bool]:
        """
        Enable this flag for force deletion of environment group
        """
        return pulumi.get(self, "force_delete")

    @_builtins.property
    @pulumi.getter
    def identifier(self) -> pulumi.Output[_builtins.str]:
        """
        identifier of the environment group.
        """
        return pulumi.get(self, "identifier")

    @_builtins.property
    @pulumi.getter(name="orgId")
    def org_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        org_id of the environment group.
        """
        return pulumi.get(self, "org_id")

    @_builtins.property
    @pulumi.getter(name="projectId")
    def project_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        project_id of the environment group.
        """
        return pulumi.get(self, "project_id")

    @_builtins.property
    @pulumi.getter
    def yaml(self) -> pulumi.Output[_builtins.str]:
        """
        Env group YAML. In YAML, to reference an entity at the organization scope, prefix 'org' to the expression: org.{identifier}. To reference an entity at the account scope, prefix 'account` to the expression: account.{identifier}. For eg, to reference a connector with identifier 'connectorId' at the organization scope in a stage mention it as connectorRef: org.connectorId.
        """
        return pulumi.get(self, "yaml")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins as _builtins
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DashboardsArgs', 'Dashboards']

@pulumi.input_type
class DashboardsArgs:
    def __init__(__self__, *,
                 dashboard_id: pulumi.Input[_builtins.str],
                 resource_identifier: pulumi.Input[_builtins.str],
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 data_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[_builtins.str]] = None,
                 models: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_count: Optional[pulumi.Input[_builtins.int]] = None):
        """
        The set of arguments for constructing a Dashboards resource.
        :param pulumi.Input[_builtins.str] dashboard_id: Unique identifier of the Template Dashboard to create from.
        :param pulumi.Input[_builtins.str] resource_identifier: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp of the Dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] data_sources: Data Sources within the Dashboard.
        :param pulumi.Input[_builtins.str] description: Description of the Dashboard.
        :param pulumi.Input[_builtins.str] folder_id: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] models: Data Models within the Dashboard.
        :param pulumi.Input[_builtins.str] name: Name of the Dashboard.
        :param pulumi.Input[_builtins.str] title: Title of the Dashboard.
        :param pulumi.Input[_builtins.str] type: Type of the dashboard.
        :param pulumi.Input[_builtins.int] view_count: View count of the dashboard.
        """
        pulumi.set(__self__, "dashboard_id", dashboard_id)
        pulumi.set(__self__, "resource_identifier", resource_identifier)
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if data_sources is not None:
            pulumi.set(__self__, "data_sources", data_sources)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if models is not None:
            pulumi.set(__self__, "models", models)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if view_count is not None:
            pulumi.set(__self__, "view_count", view_count)

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> pulumi.Input[_builtins.str]:
        """
        Unique identifier of the Template Dashboard to create from.
        """
        return pulumi.get(self, "dashboard_id")

    @dashboard_id.setter
    def dashboard_id(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "dashboard_id", value)

    @_builtins.property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> pulumi.Input[_builtins.str]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "resource_identifier")

    @resource_identifier.setter
    def resource_identifier(self, value: pulumi.Input[_builtins.str]):
        pulumi.set(self, "resource_identifier", value)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created at timestamp of the Dashboard.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="dataSources")
    def data_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Data Sources within the Dashboard.
        """
        return pulumi.get(self, "data_sources")

    @data_sources.setter
    def data_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "data_sources", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Dashboard.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "folder_id", value)

    @_builtins.property
    @pulumi.getter
    def models(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Data Models within the Dashboard.
        """
        return pulumi.get(self, "models")

    @models.setter
    def models(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "models", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Title of the Dashboard.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the dashboard.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="viewCount")
    def view_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        View count of the dashboard.
        """
        return pulumi.get(self, "view_count")

    @view_count.setter
    def view_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "view_count", value)


@pulumi.input_type
class _DashboardsState:
    def __init__(__self__, *,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 favorite_count: Optional[pulumi.Input[_builtins.int]] = None,
                 folder_id: Optional[pulumi.Input[_builtins.str]] = None,
                 last_accessed_at: Optional[pulumi.Input[_builtins.str]] = None,
                 models: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_count: Optional[pulumi.Input[_builtins.int]] = None):
        """
        Input properties used for looking up and filtering Dashboards resources.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp of the Dashboard.
        :param pulumi.Input[_builtins.str] dashboard_id: Unique identifier of the Template Dashboard to create from.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] data_sources: Data Sources within the Dashboard.
        :param pulumi.Input[_builtins.str] description: Description of the Dashboard.
        :param pulumi.Input[_builtins.int] favorite_count: Favorite count of the dashboard.
        :param pulumi.Input[_builtins.str] folder_id: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] last_accessed_at: Last accessed at timestamp of the Dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] models: Data Models within the Dashboard.
        :param pulumi.Input[_builtins.str] name: Name of the Dashboard.
        :param pulumi.Input[_builtins.str] resource_identifier: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] title: Title of the Dashboard.
        :param pulumi.Input[_builtins.str] type: Type of the dashboard.
        :param pulumi.Input[_builtins.int] view_count: View count of the dashboard.
        """
        if created_at is not None:
            pulumi.set(__self__, "created_at", created_at)
        if dashboard_id is not None:
            pulumi.set(__self__, "dashboard_id", dashboard_id)
        if data_sources is not None:
            pulumi.set(__self__, "data_sources", data_sources)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if favorite_count is not None:
            pulumi.set(__self__, "favorite_count", favorite_count)
        if folder_id is not None:
            pulumi.set(__self__, "folder_id", folder_id)
        if last_accessed_at is not None:
            pulumi.set(__self__, "last_accessed_at", last_accessed_at)
        if models is not None:
            pulumi.set(__self__, "models", models)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if resource_identifier is not None:
            pulumi.set(__self__, "resource_identifier", resource_identifier)
        if title is not None:
            pulumi.set(__self__, "title", title)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if view_count is not None:
            pulumi.set(__self__, "view_count", view_count)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Created at timestamp of the Dashboard.
        """
        return pulumi.get(self, "created_at")

    @created_at.setter
    def created_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "created_at", value)

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Unique identifier of the Template Dashboard to create from.
        """
        return pulumi.get(self, "dashboard_id")

    @dashboard_id.setter
    def dashboard_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "dashboard_id", value)

    @_builtins.property
    @pulumi.getter(name="dataSources")
    def data_sources(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Data Sources within the Dashboard.
        """
        return pulumi.get(self, "data_sources")

    @data_sources.setter
    def data_sources(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "data_sources", value)

    @_builtins.property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Description of the Dashboard.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "description", value)

    @_builtins.property
    @pulumi.getter(name="favoriteCount")
    def favorite_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        Favorite count of the dashboard.
        """
        return pulumi.get(self, "favorite_count")

    @favorite_count.setter
    def favorite_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "favorite_count", value)

    @_builtins.property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "folder_id")

    @folder_id.setter
    def folder_id(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "folder_id", value)

    @_builtins.property
    @pulumi.getter(name="lastAccessedAt")
    def last_accessed_at(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Last accessed at timestamp of the Dashboard.
        """
        return pulumi.get(self, "last_accessed_at")

    @last_accessed_at.setter
    def last_accessed_at(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "last_accessed_at", value)

    @_builtins.property
    @pulumi.getter
    def models(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]:
        """
        Data Models within the Dashboard.
        """
        return pulumi.get(self, "models")

    @models.setter
    def models(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]]):
        pulumi.set(self, "models", value)

    @_builtins.property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Name of the Dashboard.
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "name", value)

    @_builtins.property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "resource_identifier")

    @resource_identifier.setter
    def resource_identifier(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "resource_identifier", value)

    @_builtins.property
    @pulumi.getter
    def title(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Title of the Dashboard.
        """
        return pulumi.get(self, "title")

    @title.setter
    def title(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "title", value)

    @_builtins.property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[_builtins.str]]:
        """
        Type of the dashboard.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[_builtins.str]]):
        pulumi.set(self, "type", value)

    @_builtins.property
    @pulumi.getter(name="viewCount")
    def view_count(self) -> Optional[pulumi.Input[_builtins.int]]:
        """
        View count of the dashboard.
        """
        return pulumi.get(self, "view_count")

    @view_count.setter
    def view_count(self, value: Optional[pulumi.Input[_builtins.int]]):
        pulumi.set(self, "view_count", value)


@pulumi.type_token("harness:platform/dashboards:Dashboards")
class Dashboards(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[_builtins.str]] = None,
                 models: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_count: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        """
        Resource for a Harness Custom Dashboard.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        dashboard = harness.platform.Dashboards("dashboard",
            dashboard_id="111",
            description="dashboard_tag",
            resource_identifier="999",
            title="Dashboard Title")
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp of the Dashboard.
        :param pulumi.Input[_builtins.str] dashboard_id: Unique identifier of the Template Dashboard to create from.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] data_sources: Data Sources within the Dashboard.
        :param pulumi.Input[_builtins.str] description: Description of the Dashboard.
        :param pulumi.Input[_builtins.str] folder_id: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] models: Data Models within the Dashboard.
        :param pulumi.Input[_builtins.str] name: Name of the Dashboard.
        :param pulumi.Input[_builtins.str] resource_identifier: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] title: Title of the Dashboard.
        :param pulumi.Input[_builtins.str] type: Type of the dashboard.
        :param pulumi.Input[_builtins.int] view_count: View count of the dashboard.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DashboardsArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Resource for a Harness Custom Dashboard.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_harness as harness

        dashboard = harness.platform.Dashboards("dashboard",
            dashboard_id="111",
            description="dashboard_tag",
            resource_identifier="999",
            title="Dashboard Title")
        ```

        :param str resource_name: The name of the resource.
        :param DashboardsArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DashboardsArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 created_at: Optional[pulumi.Input[_builtins.str]] = None,
                 dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
                 data_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 description: Optional[pulumi.Input[_builtins.str]] = None,
                 folder_id: Optional[pulumi.Input[_builtins.str]] = None,
                 models: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
                 name: Optional[pulumi.Input[_builtins.str]] = None,
                 resource_identifier: Optional[pulumi.Input[_builtins.str]] = None,
                 title: Optional[pulumi.Input[_builtins.str]] = None,
                 type: Optional[pulumi.Input[_builtins.str]] = None,
                 view_count: Optional[pulumi.Input[_builtins.int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DashboardsArgs.__new__(DashboardsArgs)

            __props__.__dict__["created_at"] = created_at
            if dashboard_id is None and not opts.urn:
                raise TypeError("Missing required property 'dashboard_id'")
            __props__.__dict__["dashboard_id"] = dashboard_id
            __props__.__dict__["data_sources"] = data_sources
            __props__.__dict__["description"] = description
            __props__.__dict__["folder_id"] = folder_id
            __props__.__dict__["models"] = models
            __props__.__dict__["name"] = name
            if resource_identifier is None and not opts.urn:
                raise TypeError("Missing required property 'resource_identifier'")
            __props__.__dict__["resource_identifier"] = resource_identifier
            __props__.__dict__["title"] = title
            __props__.__dict__["type"] = type
            __props__.__dict__["view_count"] = view_count
            __props__.__dict__["favorite_count"] = None
            __props__.__dict__["last_accessed_at"] = None
        super(Dashboards, __self__).__init__(
            'harness:platform/dashboards:Dashboards',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            created_at: Optional[pulumi.Input[_builtins.str]] = None,
            dashboard_id: Optional[pulumi.Input[_builtins.str]] = None,
            data_sources: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            description: Optional[pulumi.Input[_builtins.str]] = None,
            favorite_count: Optional[pulumi.Input[_builtins.int]] = None,
            folder_id: Optional[pulumi.Input[_builtins.str]] = None,
            last_accessed_at: Optional[pulumi.Input[_builtins.str]] = None,
            models: Optional[pulumi.Input[Sequence[pulumi.Input[_builtins.str]]]] = None,
            name: Optional[pulumi.Input[_builtins.str]] = None,
            resource_identifier: Optional[pulumi.Input[_builtins.str]] = None,
            title: Optional[pulumi.Input[_builtins.str]] = None,
            type: Optional[pulumi.Input[_builtins.str]] = None,
            view_count: Optional[pulumi.Input[_builtins.int]] = None) -> 'Dashboards':
        """
        Get an existing Dashboards resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[_builtins.str] created_at: Created at timestamp of the Dashboard.
        :param pulumi.Input[_builtins.str] dashboard_id: Unique identifier of the Template Dashboard to create from.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] data_sources: Data Sources within the Dashboard.
        :param pulumi.Input[_builtins.str] description: Description of the Dashboard.
        :param pulumi.Input[_builtins.int] favorite_count: Favorite count of the dashboard.
        :param pulumi.Input[_builtins.str] folder_id: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] last_accessed_at: Last accessed at timestamp of the Dashboard.
        :param pulumi.Input[Sequence[pulumi.Input[_builtins.str]]] models: Data Models within the Dashboard.
        :param pulumi.Input[_builtins.str] name: Name of the Dashboard.
        :param pulumi.Input[_builtins.str] resource_identifier: The Folder ID that the Dashboard belongs to.
        :param pulumi.Input[_builtins.str] title: Title of the Dashboard.
        :param pulumi.Input[_builtins.str] type: Type of the dashboard.
        :param pulumi.Input[_builtins.int] view_count: View count of the dashboard.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DashboardsState.__new__(_DashboardsState)

        __props__.__dict__["created_at"] = created_at
        __props__.__dict__["dashboard_id"] = dashboard_id
        __props__.__dict__["data_sources"] = data_sources
        __props__.__dict__["description"] = description
        __props__.__dict__["favorite_count"] = favorite_count
        __props__.__dict__["folder_id"] = folder_id
        __props__.__dict__["last_accessed_at"] = last_accessed_at
        __props__.__dict__["models"] = models
        __props__.__dict__["name"] = name
        __props__.__dict__["resource_identifier"] = resource_identifier
        __props__.__dict__["title"] = title
        __props__.__dict__["type"] = type
        __props__.__dict__["view_count"] = view_count
        return Dashboards(resource_name, opts=opts, __props__=__props__)

    @_builtins.property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> pulumi.Output[_builtins.str]:
        """
        Created at timestamp of the Dashboard.
        """
        return pulumi.get(self, "created_at")

    @_builtins.property
    @pulumi.getter(name="dashboardId")
    def dashboard_id(self) -> pulumi.Output[_builtins.str]:
        """
        Unique identifier of the Template Dashboard to create from.
        """
        return pulumi.get(self, "dashboard_id")

    @_builtins.property
    @pulumi.getter(name="dataSources")
    def data_sources(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Data Sources within the Dashboard.
        """
        return pulumi.get(self, "data_sources")

    @_builtins.property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Description of the Dashboard.
        """
        return pulumi.get(self, "description")

    @_builtins.property
    @pulumi.getter(name="favoriteCount")
    def favorite_count(self) -> pulumi.Output[_builtins.int]:
        """
        Favorite count of the dashboard.
        """
        return pulumi.get(self, "favorite_count")

    @_builtins.property
    @pulumi.getter(name="folderId")
    def folder_id(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "folder_id")

    @_builtins.property
    @pulumi.getter(name="lastAccessedAt")
    def last_accessed_at(self) -> pulumi.Output[_builtins.str]:
        """
        Last accessed at timestamp of the Dashboard.
        """
        return pulumi.get(self, "last_accessed_at")

    @_builtins.property
    @pulumi.getter
    def models(self) -> pulumi.Output[Sequence[_builtins.str]]:
        """
        Data Models within the Dashboard.
        """
        return pulumi.get(self, "models")

    @_builtins.property
    @pulumi.getter
    def name(self) -> pulumi.Output[_builtins.str]:
        """
        Name of the Dashboard.
        """
        return pulumi.get(self, "name")

    @_builtins.property
    @pulumi.getter(name="resourceIdentifier")
    def resource_identifier(self) -> pulumi.Output[_builtins.str]:
        """
        The Folder ID that the Dashboard belongs to.
        """
        return pulumi.get(self, "resource_identifier")

    @_builtins.property
    @pulumi.getter
    def title(self) -> pulumi.Output[Optional[_builtins.str]]:
        """
        Title of the Dashboard.
        """
        return pulumi.get(self, "title")

    @_builtins.property
    @pulumi.getter
    def type(self) -> pulumi.Output[_builtins.str]:
        """
        Type of the dashboard.
        """
        return pulumi.get(self, "type")

    @_builtins.property
    @pulumi.getter(name="viewCount")
    def view_count(self) -> pulumi.Output[_builtins.int]:
        """
        View count of the dashboard.
        """
        return pulumi.get(self, "view_count")

